@@ -1,8 +1,6 @@
 #ifndef _LIBXMLPP_CONFIG_H
 #define _LIBXMLPP_CONFIG_H
 
-#include <glibmmconfig.h>
-
 /* Define to omit deprecated API from the library. */
 /* #undef LIBXMLXX_DISABLE_DEPRECATED */
 
@@ -10,15 +8,22 @@
 #define LIBXMLXX_HAVE_EXCEPTION_PTR 1
 
 /* Major version number of libxml++. */
-#define LIBXMLXX_MAJOR_VERSION 3
+#define LIBXMLXX_MAJOR_VERSION 5
 
 /* Minor version number of libxml++. */
-#define LIBXMLXX_MINOR_VERSION 2
+#define LIBXMLXX_MINOR_VERSION 0
 
 /* Micro version number of libxml++. */
-#define LIBXMLXX_MICRO_VERSION 4
+#define LIBXMLXX_MICRO_VERSION 2
 
-#if defined (GLIBMM_DLL) && !defined (LIBXMLXX_STATIC)
+#undef LIBXMLXX_STATIC
+
+// Enable DLL-specific stuff only when not building a static library
+#if !defined(__CYGWIN__) && (defined(__MINGW32__) || defined(_MSC_VER)) && !defined(LIBXMLXX_STATIC)
+# define LIBXMLPP_DLL 1
+#endif
+
+#ifdef LIBXMLPP_DLL
   #ifdef LIBXMLPP_BUILD
     #define LIBXMLPP_API __declspec(dllexport)
   #elif !defined (__GNUC__)
@@ -32,3 +37,4 @@
 #endif /* GLIBMM_DLL */
 
 #endif /* _LIBXMLPP_CONFIG_H */
+
